@@ -19,7 +19,19 @@ def client_session_fixture(ws_client):
         yield session
 
 
-def test_server_version(client_session, url, ws_client, result, capsys):
+@pytest.fixture(name="no_get_log_config_client_session")
+def no_get_log_config_client_session_fixture(no_get_log_config_ws_client):
+    """Mock the aiohttp client session that doesn't call get_log_config."""
+    with patch("aiohttp.ClientSession") as session:
+        session.return_value.__aenter__.return_value.ws_connect.side_effect = AsyncMock(
+            return_value=no_get_log_config_ws_client
+        )
+        yield session
+
+
+def test_server_version(
+    no_get_log_config_client_session, url, no_get_log_config_ws_client, result, capsys
+):
     """Test print server version."""
     with patch.object(
         sys, "argv", ["zwave_js_server", url, "--server-version"]
@@ -33,12 +45,14 @@ def test_server_version(client_session, url, ws_client, result, capsys):
         "Server: test_server_version\n"
         "Home ID: test_home_id\n"
     )
-    assert ws_client.receive_json.call_count == 1
-    assert ws_client.close.call_count == 1
+    assert no_get_log_config_ws_client.receive_json.call_count == 1
+    assert no_get_log_config_ws_client.close.call_count == 1
 
 
 @pytest.mark.parametrize("result", ["test_result"])
-def test_dump_state(client_session, url, ws_client, result, capsys):
+def test_dump_state(
+    no_get_log_config_client_session, url, no_get_log_config_ws_client, result, capsys
+):
     """Test dump state."""
     with patch.object(
         sys, "argv", ["zwave_js_server", url, "--dump-state"]
@@ -55,8 +69,8 @@ def test_dump_state(client_session, url, ws_client, result, capsys):
         "test_result\n"
     )
 
-    assert ws_client.receive_json.call_count == 3
-    assert ws_client.close.call_count == 1
+    assert no_get_log_config_ws_client.receive_json.call_count == 3
+    assert no_get_log_config_ws_client.close.call_count == 1
 
 
 def test_connect(client_session, url, ws_client):
